@@ -26,18 +26,10 @@
 
 #ifndef PHP_SCRYPT_HEADER
 #define PHP_SCRYPT_HEADER 1
-#define PHP_SCRYPT_VERSION "1.4.3"
+#define PHP_SCRYPT_VERSION "2.0.0"
 #define PHP_SCRYPT_EXTNAME "scrypt"
 
-PHP_FUNCTION(scrypt);
-PHP_FUNCTION(scrypt_pickparams);
-
 extern zend_module_entry scrypt_module_entry;
 #define phpext_scrypt_ptr &scrypt_module_entry
 
-#ifndef TSRMLS_CC
-#define TSRMLS_CC
-#define TSRMLS_FETCH()
-#endif
-
 #endif
